@@ -511,7 +511,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
         Carries out the search.
         """
         SearchDialog.searchOrder = self.searchOrderSelector.currentIndex()
-        searchString = unicode(self.lineEdit.text())
+        searchString = unicode(self.lineEdit.text(), "utf-8")
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
         if searchString in SearchDialog.recentSearches:
@@ -717,7 +717,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
     @pyqtSignature("")
     def on_donateButton_clicked(self):
         """
-        Slot documentation goes here.
+        Gimme your $$$$!
         """
         os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=stuhowarth77%40gmail%2ecom&lc=GB&item_name=cuteTube&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted'")
         self.close()
