@@ -55,6 +55,33 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.connect(self.actionAddToFavourites, SIGNAL("triggered()"), self.addToFavourites)
         self.connect(self.actionDeleteVideo, SIGNAL("triggered()"), self.confirmVideoDelete)
         self.connect(self.actionEditVideo, SIGNAL("triggered()"), self.editVideo)
+        self.connect(self.moreButton, SIGNAL("pressed()"), self.changeButtonStyleSheet)
+        self.connect(self.moreButton, SIGNAL("released()"), self.changeButtonStyleSheet)
+        self.orientationChanged()
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
+        
+    def changeButtonStyleSheet(self):
+        """
+        Setting the QToolButton style sheets in the conventional 
+        way caused trouble with the Maemo specific widgets, so 
+        I'm using a signal instead.
+        """
+        button = self.sender()
+        if button.isDown():
+            self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(120, 120, 120, 150)")
+        else:
+            self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(0, 0, 0, 150)")
+        
+    def orientationChanged(self):
+        """
+        Sets the position of the 'more' button according to 
+        the screen orientation.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.moreButton.setGeometry(QRect(407, 670, 80, 80))
+        else:
+            self.moreButton.setGeometry(QRect(727, 352, 80, 80))
 
     def filterList(self, event):
         """
@@ -185,12 +212,20 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         
     def getMoreResults(self, scrollBarPos):
         """
-        Appends more results to the list when the user scrolls 
-        to the end of the existing results.
+        Shows the 'more' button to enable the user to 
+        get more results.
         """
-        if scrollBarPos > self.minScrollPos and scrollBarPos > (self.results - 10) * 79:
-            self.minScrollPos = scrollBarPos
-            self.loadData()
+        if self.yt.isFinished() and self.results >= 25 and scrollBarPos > (self.results - 10) * 79:
+            self.moreButton.setVisible(True)
+        else:
+            self.moreButton.setVisible(False)
+                
+    @pyqtSignature("")
+    def on_moreButton_clicked(self):
+        """
+        Appends more results to the list
+        """
+        self.loadData()
 
     def reloadData(self):
         """
@@ -429,7 +464,6 @@ class MostRecentWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_recent"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -455,7 +489,6 @@ class MostViewedWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_viewed?time=today"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -482,7 +515,6 @@ class SearchResultsWindow(CutetubeWindows):
         self.searchString = searchString
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.info = False
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
@@ -523,7 +555,7 @@ class SearchResultsWindow(CutetubeWindows):
         Hides the progress indicator and informs the user if there are no results.
         """
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
-        if not self.info:
+        if not (self.info or isBusy):
             if self.results == 0:
                 QMaemo5InformationBox.information(self,  "No results found for \'%s\'" % self.searchString)
             self.info == True
@@ -549,7 +581,6 @@ class UploadsWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/uploads"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -588,7 +619,6 @@ class UserWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/%s/uploads" % self.username
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -621,7 +651,6 @@ class RelatedVideosWindow(CutetubeWindows):
         self.video = video
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = video.link[4].href
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -657,7 +686,6 @@ class FavouritesWindow(CutetubeWindows):
         self.connect(self.actionRemoveFromFavourites, SIGNAL("triggered()"), self.removeFromFavourites)        
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/favorites"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -822,7 +850,6 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.connect(self.actionRemoveFromPlaylist, SIGNAL("triggered()"), self.removeFromPlaylist)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId.split("/")[-1]
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -1158,7 +1185,6 @@ class NewSubscriptionVideosWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
-        self.minScrollPos = 0
         self.show()
         try:
             QMaemo5InformationBox.information(self, "Showing latest videos from your subscriptions")
