@@ -48,18 +48,10 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.actionRateVideo.setVisible(False)
             self.actionUserVideos.setVisible(False)
             self.actionEditVideo.setVisible(True)
-        self.videoPlayed = False
         self.show()
         self.loadData()
-        
-    def closeEvent(self):
-        """
-        Removes the temporary playback file if one exists.
-        """
-        if self.videoPlayed:
-            os.remove(self.yt.tempfile)
-        
 
+        
     def orientationChanged(self):
         """
         Re-orders the widgets when the application 
@@ -152,7 +144,6 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         try:
             self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, self.video)
             self.ytPlayer.start()
-            self.videoPlayed = True
             #self.connect(self.ytPlayer, SIGNAL("playbackFinshed(bool)"), self.toggleBusy)
             QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
         except:
