@@ -212,18 +212,12 @@ class YouTubeVideoFeed(QThread):
         """
         Retrieves and returns the video feed.
         """
-        self.emit(SIGNAL("feedCompleted(bool)"), True)
         try:
             self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "?start-index=%s" % unicode(self.results + 1))
         except:
-            try:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "&start-index=%s" % unicode(self.results + 1))
-            except:
-                pass
-        self.emit(SIGNAL("feedCompleted(bool)"), False)
+            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "&start-index=%s" % unicode(self.results + 1))
             
     def getVideoData(self):
-        self.emit(SIGNAL("feedCompleted(bool)"), True)
         for video in self.ytVideoFeed.entry:
             try:
                 thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
@@ -233,13 +227,12 @@ class YouTubeVideoFeed(QThread):
                 self.results += 1
             except:
                 pass
-        self.emit(SIGNAL("feedCompleted(bool)"), False)        
 
     def run(self):
-        if self.results == 0:
-            self.getVideoFeed() 
+        self.emit(SIGNAL("feedCompleted(bool)"), True)
+        self.getVideoFeed() 
         self.getVideoData()
-        self.getVideoFeed()
+        self.emit(SIGNAL("feedCompleted(bool)"), False)
 
 class YouTubeQueueFeed(QThread):
     """
@@ -300,7 +293,8 @@ class YouTubePlaylistFeed(QThread):
         """
         Retrieves and returns the user's playlist feed.
         """
-        self.playlistFeed = YouTubeDataService.ytService.GetYouTubePlaylistFeed()
+        playlistsUri = "http://gdata.youtube.com/feeds/api/users/default/playlists?max-results=50"
+        self.playlistFeed = YouTubeDataService.ytService.GetYouTubePlaylistFeed(uri = playlistsUri)
         self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.playlistFeed.entry)
     
     def run(self):
@@ -320,7 +314,8 @@ class YouTubeSubscriptionsFeed(QThread):
         """
         Retrieves the user's subscriptions feed.
         """
-        self.subscriptionsFeed = YouTubeDataService.ytService.GetYouTubeSubscriptionFeed()
+        subscriptionsUri = "http://gdata.youtube.com/feeds/api/users/default/subscriptions?max-results=50"
+        self.subscriptionsFeed = YouTubeDataService.ytService.GetYouTubeSubscriptionFeed(uri = subscriptionsUri)
         self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.subscriptionsFeed.entry)
 
     def run(self):
